pub trait CreateBoxedSignalStorage<T: Readable + ?Sized>: BoxedSignalStorage<T::Target> + 'static { }Expand description
A trait for creating boxed readable and writable signals. This is implemented for UnsyncStorage and SyncStorage.
The storage type must implement CreateReadOnlySignalStorage<T> for every readable T type
to be used with ReadSignal and WriteSignal.
You may need to add this trait as a bound when you call ReadSignal::new_maybe_sync or WriteSignal::new_maybe_sync while remaining generic over syncness.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".