pub trait ReadableBoxExt: Readable<Storage = UnsyncStorage> {
// Provided method
fn boxed(self) -> ReadSignal<Self::Target>
where Self: Sized + 'static { ... }
}Expand description
An extension trait for Readable types that can be boxed into a trait object.
Provided Methods
Sourcefn boxed(self) -> ReadSignal<Self::Target>where
Self: Sized + 'static,
fn boxed(self) -> ReadSignal<Self::Target>where
Self: Sized + 'static,
Box the readable value into a trait object. This is useful for passing around readable values without knowing their concrete type.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".