pub trait WritableBoxedExt: Writable<Storage = UnsyncStorage> {
// Provided method
fn boxed_mut(self) -> WriteSignal<Self::Target>
where Self: Sized + 'static { ... }
}Expand description
An extension trait for Writable values that can be boxed into a trait object.
Provided Methods
Sourcefn boxed_mut(self) -> WriteSignal<Self::Target>where
Self: Sized + 'static,
fn boxed_mut(self) -> WriteSignal<Self::Target>where
Self: Sized + 'static,
Box the writable value into a trait object. This is useful for passing around writable values without knowing their concrete type.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".